@@ -2,12 +2,19 @@
 
 import sys
 import pathlib
+import traceback
 
 import click
 from click.exceptions import ClickException
 
 from honeybee_vtk.model import Model
 from honeybee_vtk.vtkjs.schema import SensorGridOptions, DisplayMode
+from honeybee_vtk.config import load_config
+from honeybee_vtk.scene import Scene
+from honeybee_vtk.camera import Camera
+from honeybee_vtk.actor import Actor
+from honeybee_vtk.types import VTKWriters
+
 
 @click.group()
 def translate():
@@ -23,28 +30,35 @@ def translate():
 @click.option(
     '--folder', '-f', help='Path to target folder.',
     type=click.Path(exists=False, file_okay=False, resolve_path=True,
-    dir_okay='True'), default='.', show_default=True
+                    dir_okay='True'), default='.', show_default=True
 )
 @click.option(
-    '--file-type', '-ft', type=click.Choice(['html', 'vtkjs'], case_sensitive=False),
-    default='html', help='Switch between html and vtkjs formats', show_default=True
+    '--file-type', '-ft', type=click.Choice(['html', 'vtkjs', 'vtp', 'vtk'],
+                                            case_sensitive=False), default='html',
+    help='Switch between html and vtkjs formats', show_default=True
 )
 @click.option(
     '--display-mode', '-dm', type=click.Choice(['shaded', 'surface',
-    'surfacewithedges', 'wireframe', 'points'], case_sensitive=False),
+                                                'surfacewithedges', 'wireframe', 'points'], case_sensitive=False),
     default='shaded', help='Set display mode for the model.', show_default=True
 )
 @click.option(
     '--grid-options', '-go', type=click.Choice(['ignore', 'points', 'meshes'],
-    case_sensitive=False), default='ignore', help='Export sensor grids as either'
+                                               case_sensitive=False), default='ignore', help='Export sensor grids as either'
     ' points or meshes.', show_default=True,
 )
 @click.option(
     '--show-html', '--show', '-sh', is_flag=True, default=False,
     help='Open the generated HTML file in a browser.', show_default=True
 )
+@click.option(
+    '--config', '-cf', help='File Path to the config json file which can be used to'
+    ' mount simulation data on HBJSON.', type=click.Path(exists=True), default=None,
+    show_default=True
+)
 def translate(
-        hbjson_file, name, folder, file_type, display_mode, grid_options, show_html):
+        hbjson_file, name, folder, file_type, display_mode, grid_options, show_html,
+        config):
     """Translate a HBJSON file to an HTML or a vtkjs file.
 
     \b
@@ -78,16 +92,33 @@ def translate(
         elif display_mode == 'points':
             model.update_display_mode(DisplayMode.Points)
 
+        # load data
+        if config:
+            scene = Scene()
+            actors = Actor.from_model(model)
+            bounds = Actor.get_bounds(actors)
+            centroid = Actor.get_centroid(actors)
+            cameras = Camera.aerial_cameras(bounds=bounds, centroid=centroid)
+            scene.add_actors(actors)
+            scene.add_cameras(cameras)
+            model = load_config(config, model, scene)
+
         # Set file type
-        if file_type == 'html':
+
+        if file_type.lower() == 'html':
             output = model.to_html(folder=folder, name=name, show=show_html)
-        else:
+        elif file_type.lower() == 'vtkjs':
             output = model.to_vtkjs(folder=folder, name=name)
-        print(output)
+        elif file_type.lower() == 'vtk':
+            output = model.to_files(folder=folder, name=name,
+                                    writer=VTKWriters.legacy)
+        elif file_type.lower() == 'vtp':
+            output = model.to_files(folder=folder, name=name,
+                                    writer=VTKWriters.binary)
+
     except Exception as e:
-        raise ClickException(f'Translation failed:\n{e}')
+        traceback.print_exc()
+        sys.exit(1)
     else:
         print(f'Success: {output}', file=sys.stderr)
         return sys.exit(0)
-
-
