@@ -1,14 +1,18 @@
 """A VTK scene."""
 
 from __future__ import annotations
+
+from typing import Dict, List, Tuple, Union
+
 import vtk
-from typing import List, Tuple, Union, Dict
+
 from ._helper import _validate_input
-from .camera import Camera
 from .actor import Actor
 from .assistant import Assistant
-from .types import ImageTypes
+from .camera import Camera
+from .headless import try_headless
 from .legend_parameter import LegendParameter
+from .types import ImageTypes
 
 
 class Scene:
@@ -43,7 +47,7 @@ class Scene:
         if not val:
             colors = vtk.vtkNamedColors()
             self._background_color = colors.GetColor3d("SlateGray")
-        elif _validate_input(val, int):
+        elif _validate_input(val, [int]):
             self._background_color = val
         else:
             raise ValueError(
@@ -86,8 +90,8 @@ class Scene:
         """
         if name not in self.legend_parameters.keys():
             raise ValueError(
-                'No legend parameter found by that name in this scene. The names of the'
-                ' legend parameters in this scene are'
+                'No legend parameter found by that name in this scene. Make sure cameras'
+                ' and actors a added to the scene. Legends in the scene are'
                 f' {tuple(self.legend_parameters.keys())}.'
             )
         return self.legend_parameters[name]
@@ -98,7 +102,7 @@ class Scene:
         Args:
             val: Either a list of Camera objects or a single Camera object.
         """
-        if isinstance(val, list) and _validate_input(val, Camera):
+        if isinstance(val, list) and _validate_input(val, [Camera]):
             self._cameras.extend(val)
         elif isinstance(val, Camera):
             self._cameras.append(val)
@@ -114,7 +118,7 @@ class Scene:
         Args:
             val: Either a list of Actors objects or a single Actor object.
         """
-        if isinstance(val, list) and _validate_input(val, Actor):
+        if isinstance(val, list) and _validate_input(val, [Actor]):
             for v in val:
                 self._actors[v.name] = v
         elif isinstance(val, Actor):
@@ -157,7 +161,7 @@ class Scene:
             if self.legend_parameters:
                 visible_legend_params = [
                     legend_param for legend_param in self.legend_parameters.values()
-                    if legend_param.show_legend]
+                    if not legend_param.hide_legend]
             else:
                 visible_legend_params = []
 
@@ -170,6 +174,7 @@ class Scene:
                 'Add cameras and actors to the scene first.'
             )
 
+    @try_headless
     def export_images(
             self, folder: str, name: str = 'Camera',
             image_type: ImageTypes = ImageTypes.png, *,
