@@ -15,18 +15,25 @@ import vtk
 from enum import Enum
 from typing import Dict, Union, List, Tuple
 from ladybug.color import Color
-from .legend_parameter import LegendParameter, Colors
+from .legend_parameter import LegendParameter, ColorSets
 from .vtkjs.schema import DataSetProperty, DataSet, DisplayMode, DataSetMapper
 
 
-model_dataset_names = ('wall', 'aperture', 'shade', 'door', 'floor', 'roofceiling',
-                       'airboundary', 'grid')
+class DataSetNames(Enum):
+    """Valid ModelDataset names."""
+    wall = 'wall'
+    aperture = 'aperture'
+    shade = 'shade'
+    door = 'door'
+    floor = 'floor'
+    roofceiling = 'roofceiling'
+    airboundary = 'airboundary'
+    grid = 'grid'
 
 
 class VTKWriters(Enum):
     """Vtk writers."""
     legacy = 'vtk'
-    ascii = 'vtp'
     binary = 'vtp'
 
 
@@ -49,7 +56,9 @@ class DataFieldInfo:
 
     Args:
         name: A string representing the name of for data.
-        range: A tuple of min, max values. Defaults to (0, 100).
+        range: A tuple of min, max values as either integers or floats.
+            Defaults to None which will create a range of minimum and maximum
+            values in the data.
         colors: A Colors object that defines colors for the legend.
             Defaults to Ecotect colorset.
         per_face : A Boolean to indicate if the data is per face or per point. In
@@ -57,19 +66,29 @@ class DataFieldInfo:
             are provided per face.
     """
 
-    def __init__(self, name: str = 'default', range: Tuple[int, int] = (0, 100),
-                 colors: Colors = Colors.ecotect, per_face: bool = True
+    def __init__(self, name: str = 'default', range: Tuple[float, float] = None,
+                 colors: ColorSets = ColorSets.ecotect, per_face: bool = True
                  ) -> None:
-
         self.name = name
+        self._range = range
         self.per_face = per_face
-        self._legend_param = LegendParameter(name=name, colors=colors, range=range)
+        self._legend_param = LegendParameter(name=name, colors=colors, auto_range=range)
 
     @property
     def legend_parameter(self) -> LegendParameter:
         """Legend associated with the DataFieldInfo object."""
         return self._legend_param
 
+    @property
+    def range(self) -> Tuple[float, float]:
+        """Range is a tuple of minimum and maximum values.
+
+        If these minimum and maximum values are not provided, they are calculated
+        automatically. In such a case, the minimum and maximum values in the data are
+        used.
+        """
+        return self._range
+
 
 class PolyData(vtk.vtkPolyData):
     """A thin wrapper around vtk.vtkPolyData.
@@ -150,7 +169,7 @@ class PolyData(vtk.vtkPolyData):
         if not data_range:
             data_range = tuple(values.GetRange())
         if not colors:
-            colors = Colors.ecotect
+            colors = ColorSets.ecotect
 
         self._fields[name] = DataFieldInfo(name, data_range, colors, cell)
 
@@ -164,15 +183,15 @@ class PolyData(vtk.vtkPolyData):
             self.GetCellData().SetActiveScalars(name)
         else:
             self.GetPointData().SetActiveScalars(name)
+
         self.Modified()
 
-    def to_vtk(self, target_folder, name, ascii=False):
+    def to_vtk(self, target_folder, name, writer):
         """Write to a VTK file.
 
         The file extension will be set to vtk for ASCII format and vtp for binary format.
         """
-        writer = VTKWriters.ascii if ascii else VTKWriters.binary
-        return _write_to_file(self, target_folder, name, writer=writer)
+        return _write_to_file(self, target_folder, name, writer)
 
     def to_folder(self, target_folder='.'):
         """Write data to a folder with a JSON meta file.
@@ -226,13 +245,12 @@ class JoinedPolyData(vtk.vtkAppendPolyData):
             self.AddInputData(data)
         self.Update()
 
-    def to_vtk(self, target_folder, name, ascii=False):
+    def to_vtk(self, target_folder, name, writer):
         """Write to a VTK file.
 
         The file extension will be set to vtk for ASCII format and vtp for binary format.
         """
-        writer = VTKWriters.ascii if ascii else VTKWriters.binary
-        return _write_to_file(self, target_folder, name, writer=writer)
+        return _write_to_file(self, target_folder, name, writer)
 
     def to_folder(self, target_folder='.'):
         """Write data to a folder with a JSON meta file.
@@ -310,7 +328,7 @@ class ModelDataSet:
 
         assert len(self.data) == len(data), \
             f'Length of input data {len(data)} does not match the length of'\
-            f' polydata in this dataset {len(self.data)}.'
+            f' {name} in this dataset {len(self.data)}.'
 
         for count, d in enumerate(data):
             self.data[count].add_data(
@@ -451,7 +469,7 @@ class ModelDataSet:
 
     def __repr__(self) -> str:
         return f'ModelDataSet: {self.name}' \
-            '\n  DataSets: {len(self.data)}\n  Color:{self.color}'
+            f'\n  DataSets: {len(self.data)}\n  Color:{self.color}'
 
 
 def _write_to_file(
@@ -459,8 +477,9 @@ def _write_to_file(
     writer: VTKWriters = VTKWriters.binary
 ):
     """Write vtkPolyData to a file."""
-    # Write as a vtk file
+
     extension = writer.value
+
     if writer.name == 'legacy':
         _writer = vtk.vtkPolyDataWriter()
     else:
