@@ -11,8 +11,8 @@ from honeybee_vtk.scene import Scene
 from honeybee_vtk.vtkjs.schema import SensorGridOptions, DisplayMode
 from honeybee_vtk.camera import Camera
 from honeybee_vtk.actor import Actor
-from honeybee_vtk.types import ImageTypes, Colors
-from honeybee_vtk.legend_parameter import LabelFormat, Orientation
+from honeybee_vtk.types import ImageTypes, ColorSets
+from honeybee_vtk.legend_parameter import DecimalCount, Orientation
 
 
 def test_export_images_from_view_file():
@@ -92,7 +92,7 @@ def test_export_images():
             radiation.append([float(data[0])])
 
     model.shades.add_data_fields(radiation, name='Radiation', data_range=(0, 2000),
-                                 colors=Colors.original)
+                                 colors=ColorSets.original)
     model.shades.color_by = 'Radiation'
     model.shades.display_mode = DisplayMode.SurfaceWithEdges
 
@@ -104,15 +104,15 @@ def test_export_images():
     scene.add_actors(actors)
 
     scene.legend_parameters['Daylight-factor'].orientation = Orientation.horizontal
-    scene.legend_parameters['Daylight-factor'].show_legend = True
+    scene.legend_parameters['Daylight-factor'].hide_legend = True
     scene.legend_parameters['Daylight-factor'].position = (0.0, 0.1)
 
     rd = scene.legend_parameter('Radiation')
     rd.orientation = Orientation.vertical
     rd.height = 0.45
     rd.width = 0.05
-    rd.label_format = LabelFormat.integer
-    rd.show_legend = True
+    rd.decimal_count = DecimalCount.integer
+    rd.hide_legend = True
     rd.position = (0.90, 0.1)
 
     # A camera setup using the constructor
